# data1
set.seed(19)
data1 <- array(rep(seq(-10, 10, length.out = 181), 360) + rnorm(360), 
               dim = c(sdate = 1, lat = 181, lon = 360))
mask1 <- drop(data1)
mask1[which(mask1 > 9 & mask1 < -9)] <- 0
mask1[which(mask1 != 0)] <- 1
dots1 <- mask1
lon1 <- -180:179
lat1 <- -90:90

#--------------------------------------------------------------------

test_that("1. Input checks", {

# data
expect_error(
  PlotRobinson(array(data1*2, dim = c(sdate = 2, lat = 181, lon = 360))),
  "Parameter 'data' must have two dimensions."
)  
# lon, lon_dim
tmp <- data1; dim(tmp) <- c(sdate = 1, latt = 181, lonn = 360)
expect_error(
  PlotRobinson(tmp), 
  "Cannot find known longitude name in data dimension. Please define parameter 'lon_dim'."
)
expect_error(
  PlotRobinson(data1, lon = 1:10),
  "Length of parameter 'lon' should match longitude dimension in 'data'."
)
# target_proj
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, target_proj = NULL),
  "Parameter 'target_proj' cannot be NULL."
)
# legend
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, legend = 1),
  "Parameter 'legend' must be NULL, ggplot2 or s2dv."
)
# style
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, style = 'line'),
  "Parameter 'style' must be 'point' or 'polygon'."
)
# dots
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, dots = c(1, 0)),
  "Parameter 'dots' must have two dimensions named as longitude and latitude dimensions in 'data'."
)
tmp <- dots1; dim(tmp) <- c(sdate = 1, lat = 360, lon = 181)
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, dots = tmp),
  "Parameter 'dots' must have the same dimensions as 'data'."
)
tmp <- dots1; tmp[1] <- NA
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, dots = tmp),
  "Parameter 'dots' must have only TRUE/FALSE or 0/1."
)
# colNA
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, colNA = 'fair'),
  "Parameter 'colNA' must be a valid colour identifier."
)
# toptitle
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, toptitle = 1:10),
  "Parameter 'toptitle' must be a character string."
)
# caption
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, caption = 1:10),
  "Parameter 'caption' must be a character string."
)
# crop_coastlines
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, crop_coastlines = c(x1 = 1, x2 = 10, y1 = -10, y2 = 10)),
  "Parameter 'crop_coastlines' needs to have names 'latmax', 'latmin', 'lonmax', 'lonmin'."
)
# point_size
expect_error(
  PlotRobinson(data1, lon = lon1, lat = lat1, point_size = 'small'),
  "Parameter 'point_size' must be a number."
)

})

#--------------------------------------------------------

test_that("2. data1", {


})
